@@ -1,10 +1,15 @@
 import base64
-import functools
 import re
 
 import tornado
 
 
+try:
+    callable
+except NameError:
+    from seesaw.six import callable
+
+
 class AuthenticationErrorHandler(tornado.web.RequestHandler):
     def initialize(self, realm="Restricted"):
         self.realm = realm
@@ -21,10 +26,12 @@ class AuthenticatedApplication(tornado.web.Application):
         self.auth_enabled = kwargs.get("auth_enabled", True)
         self.auth_realm = kwargs.get("auth_realm", "Restricted")
         self.check_auth = kwargs.get("check_auth")
-        self.skip_auth = [re.compile(pattern) for pattern in kwargs.get("skip_auth", [])]
+        self.skip_auth = [re.compile(pattern)
+                          for pattern in kwargs.get("skip_auth", [])]
 
     def __call__(self, request):
-        if not self.auth_enabled or (callable(self.auth_enabled) and not self.auth_enabled()):
+        if not self.auth_enabled or (callable(self.auth_enabled) and
+                                     not self.auth_enabled()):
             return super(AuthenticatedApplication, self).__call__(request)
 
         for pattern in self.skip_auth:
@@ -37,9 +44,11 @@ class AuthenticatedApplication(tornado.web.Application):
             username, password = auth_decoded.split(':', 2)
             request.basicauth_user, request.basicauth_pass = username, password
 
-            if self.check_auth and self.check_auth(request, username, password):
+            if self.check_auth and \
+                    self.check_auth(request, username, password):
                 return super(AuthenticatedApplication, self).__call__(request)
 
-        handler = AuthenticationErrorHandler(self, request, realm=self.auth_realm)
+        handler = AuthenticationErrorHandler(self, request,
+                                             realm=self.auth_realm)
         handler._execute([])
         return handler
